@@ -20,7 +20,7 @@
 #include <pcre.h>
 #include "common_options.h"
 #define MYLOADER_MODE "myloader_mode"
-#define IS_INNODB_TABLE 2
+#define IS_TRX_TABLE 2
 #define INCLUDE_CONSTRAINT 4
 #define IS_ALTER_TABLE_PRESENT 8
 #define START_SLAVE "START SLAVE"
@@ -88,6 +88,7 @@ struct configuration_per_table{
 };
 
 #define STREAM_BUFFER_SIZE 1000000
+#define STREAM_BUFFER_SIZE_NO_STREAM 100
 #define DEFAULTS_FILE "/etc/mydumper.cnf"
 struct function_pointer;
 typedef gchar * (*fun_ptr)(gchar **,gulong*, struct function_pointer*);
@@ -106,6 +107,7 @@ struct function_pointer{
   GHashTable *memory;
   gboolean replace_null;
   guint max_length;
+  guint null_max_length;
   GList *unique_list;
   gboolean unique;
 };
