@@ -20,3 +20,23 @@
 
 #define BACKTICK '`'
 #define DOUBLE_QUOTE '"'
+#define TRADITIONAL 0
+#define AWS 1
+
+extern char identifier_quote_character;
+extern const char *identifier_quote_character_str;
+extern guint max_threads_per_table;
+extern gchar *set_names_str;
+extern gchar *set_names_statement;
+extern gboolean no_stream;
+extern gboolean stream;
+extern gboolean no_delete;
+extern gchar *defaults_file;
+extern char *defaults_extra_file;
+extern GKeyFile * key_file;
+extern guint num_threads;
+extern MYSQL *main_connection;
+extern GString *set_global_back;
+extern gboolean no_sync;
+
+
