@@ -23,8 +23,26 @@
 void initialize_connection(const gchar *app);
 //void initialize_connection(gchar *cdf, const gchar *group, const gchar *app);
 void set_connection_defaults_file_and_group(gchar *cdf, const gchar *group);
-void m_connect(MYSQL *conn, gchar *schema);
+void m_connect(MYSQL *conn);
+//void m_connect(MYSQL *conn, gchar *schema);
 void hide_password(int argc, char *argv[]);
 void ask_password();
 GOptionGroup * load_connection_entries(GOptionContext *context);
+
+extern char *hostname;
+extern char *username;
+extern char *password;
+extern gboolean askPassword;
+extern char *socket_path;
+extern guint port;
+extern char *tls_version; 
+extern char *capath;
+extern char *key;
+extern char *cert;
+extern char *ca;
+extern gboolean ssl;
+extern gchar *ssl_mode;
+extern char *cipher;
+extern gboolean compress_protocol;
+extern char *protocol_str;
 #endif
