@@ -38,6 +38,9 @@ guint output_format=SQL_INSERT;
 gchar *output_directory_str = NULL;
 gboolean masquerade_filename=FALSE;
 gboolean trx_tables=FALSE;
+gboolean use_single_column=FALSE;
+const gchar *table_engine_for_view_dependency=MEMORY;
+
 
 gboolean arguments_callback(const gchar *option_name,const gchar *value, gpointer data, GError **error){
   *error=NULL;
@@ -243,6 +246,8 @@ static GOptionEntry daemon_entries[] = {
 static GOptionEntry chunks_entries[] = {
     {"max-threads-per-table", 0, 0, G_OPTION_ARG_INT, &max_threads_per_table,
      "Maximum number of threads per table to use", NULL},
+    {"use-single-column", 0, 0, G_OPTION_ARG_NONE, &use_single_column, 
+     "It will ignore if the table has multiple columns and use only the first column to split the table", NULL},
     {"char-deep", 0, 0, G_OPTION_ARG_INT64, &char_deep,
      "Defines the amount of characters to use when the primary key is a string",NULL},
     {"char-chunk", 0, 0, G_OPTION_ARG_INT64, &char_chunk,
@@ -345,6 +350,8 @@ static GOptionEntry statement_entries[] = {
     {"skip-tz-utc", 0, 0, G_OPTION_ARG_NONE, &skip_tz, "Doesn't add SET TIMEZONE on the backup files", NULL},
     { "set-names",0, 0, G_OPTION_ARG_STRING, &set_names_str,
       "Sets the names, use it at your own risk, default binary", NULL },
+    {"table-engine-for-view-dependency", 0, 0, G_OPTION_ARG_STRING, &table_engine_for_view_dependency, 
+      "Table engine to be use for the CREATE TABLE statement for temporary tables when using views",NULL},
     {NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL}};
 
 GOptionContext * load_contex_entries(){
