@@ -39,7 +39,7 @@
 #include "mydumper_common.h"
 
 
-guint64 min_integer_chunk_step_size=1000;
+guint64 min_integer_chunk_step_size=0;
 guint64 max_integer_chunk_step_size=0;
 
 guint64 gint64_abs(gint64 a){
@@ -56,14 +56,14 @@ void initialize_integer_step(union chunk_step *cs, gboolean is_unsigned, union t
     cs->integer_step.type.unsign.min = type.unsign.min;
     cs->integer_step.type.unsign.cursor = cs->integer_step.type.unsign.min;
     cs->integer_step.type.unsign.max = type.unsign.max;
-    cs->integer_step.step = step!=0?step:(max_integer_chunk_step_size!=0?((cs->integer_step.type.unsign.max - cs->integer_step.type.unsign.min)/num_threads>max_integer_chunk_step_size?max_integer_chunk_step_size:(cs->integer_step.type.unsign.max - cs->integer_step.type.unsign.min)/num_threads):(cs->integer_step.type.unsign.max - cs->integer_step.type.unsign.min)/num_threads);
-    cs->integer_step.estimated_remaining_steps=cs->integer_step.step>0?(cs->integer_step.type.unsign.max - cs->integer_step.type.unsign.min) / cs->integer_step.step:1;
+    cs->integer_step.step = step;
+    cs->integer_step.estimated_remaining_steps=(cs->integer_step.type.unsign.max - cs->integer_step.type.unsign.min) / cs->integer_step.step;
   }else{
     cs->integer_step.type.sign.min = type.sign.min;
     cs->integer_step.type.sign.cursor = cs->integer_step.type.sign.min;
     cs->integer_step.type.sign.max = type.sign.max;
-    cs->integer_step.step = step!=0?step:(max_integer_chunk_step_size!=0?(gint64_abs(cs->integer_step.type.sign.max - cs->integer_step.type.sign.min)/num_threads>max_integer_chunk_step_size?max_integer_chunk_step_size:gint64_abs(cs->integer_step.type.sign.max - cs->integer_step.type.sign.min)/num_threads):gint64_abs(cs->integer_step.type.sign.max - cs->integer_step.type.sign.min)/num_threads);
-    cs->integer_step.estimated_remaining_steps=cs->integer_step.step>0?(cs->integer_step.type.sign.max - cs->integer_step.type.sign.min) / cs->integer_step.step:1;
+    cs->integer_step.step = step;
+    cs->integer_step.estimated_remaining_steps=(cs->integer_step.type.sign.max - cs->integer_step.type.sign.min) / cs->integer_step.step;
   }
   cs->integer_step.is_step_fixed_length = is_step_fixed_length;
   cs->integer_step.check_max=check_max;
@@ -286,6 +286,7 @@ struct chunk_step_item *get_next_integer_chunk(struct db_table *dbt){
             if (new_csi_next){
               csi->deep=csi->deep+1;
               new_csi=clone_chunk_step_item(csi);
+              new_csi->status=ASSIGNED;
               if ( csi->chunk_step->integer_step.is_step_fixed_length ){
                 new_csi->number+=pow(2,csi->deep);
               }
@@ -368,7 +369,7 @@ end:
   return NULL;
 }
 
-void refresh_integer_min_max(MYSQL *conn, struct db_table *dbt, struct chunk_step_item *csi ){
+gboolean refresh_integer_min_max(MYSQL *conn, struct db_table *dbt, struct chunk_step_item *csi ){
   struct integer_step * ics = &(csi->chunk_step->integer_step);
   gchar *query = NULL;
   MYSQL_ROW row = NULL;
@@ -385,13 +386,13 @@ void refresh_integer_min_max(MYSQL *conn, struct db_table *dbt, struct chunk_ste
   minmax = mysql_store_result(conn);
 
   if (!minmax){
-    return;
+    return FALSE;
   }
   row = mysql_fetch_row(minmax);
 
   if (row==NULL || row[0]==NULL){
     mysql_free_result(minmax);
-    return;
+    return FALSE;
   }
   if (ics->is_unsigned) {
     guint64 nmin = strtoull(row[0], NULL, 10);
@@ -406,6 +407,7 @@ void refresh_integer_min_max(MYSQL *conn, struct db_table *dbt, struct chunk_ste
   }
   csi->include_null=TRUE;
   mysql_free_result(minmax);
+  return TRUE;
 }
 
 
@@ -517,14 +519,28 @@ guint process_integer_chunk_step(struct table_job *tj, struct chunk_step_item *c
   csi->status = DUMPING_CHUNK;
 
   if (cs->integer_step.check_max && tj->dbt->max_chunk_step_size!=0){
-    g_debug("Thread %d: Updating MAX", td->thread_id);
+    trace("Thread %d: Updating MAX", td->thread_id);
+    if (cs->integer_step.is_unsigned)
+      trace("Thread %d: Updating MAX: %ld", td->thread_id, cs->integer_step.type.unsign.max);
+    else
+      trace("Thread %d: Updating MAX: %ld", td->thread_id, cs->integer_step.type.sign.max);
     update_integer_max(td->thrconn, tj->dbt, csi);
+    if (cs->integer_step.is_unsigned)
+      trace("Thread %d: New MAX: %ld", td->thread_id, cs->integer_step.type.unsign.max);
+    else
+      trace("Thread %d: New MAX: %ld", td->thread_id, cs->integer_step.type.sign.max);
     cs->integer_step.check_max=FALSE;
   }
   if (cs->integer_step.check_min && tj->dbt->max_chunk_step_size!=0){
-    g_debug("Thread %d: Updating MIN", td->thread_id);
+    if (cs->integer_step.is_unsigned)
+      trace("Thread %d: Updating MIN: %ld", td->thread_id, cs->integer_step.type.unsign.min);
+    else
+      trace("Thread %d: Updating MIN: %ld", td->thread_id, cs->integer_step.type.sign.min);
     update_integer_min(td->thrconn, tj->dbt, csi);
-//    g_message("thread: %d New MIN: %ld", td->thread_id, tj->chunk_step->integer_step.nmin);
+    if (cs->integer_step.is_unsigned)
+      trace("Thread %d: New MIN: %ld", td->thread_id, cs->integer_step.type.unsign.min);
+    else
+      trace("Thread %d: New MIN: %ld", td->thread_id, cs->integer_step.type.sign.min);
     cs->integer_step.check_min=FALSE;
   }
 
@@ -537,6 +553,9 @@ guint process_integer_chunk_step(struct table_job *tj, struct chunk_step_item *c
     else
       cs->integer_step.type.unsign.cursor = cs->integer_step.type.unsign.min + cs->integer_step.step - 1;
 
+    if (cs->integer_step.type.unsign.cursor < cs->integer_step.type.unsign.min)
+      g_error("integer_step.type.unsign.cursor: %"G_GUINT64_FORMAT"  | integer_step.type.unsign.min %"G_GUINT64_FORMAT"  | cs->integer_step.type.unsign.max : %"G_GUINT64_FORMAT" | cs->integer_step.step %ld", cs->integer_step.type.unsign.cursor, cs->integer_step.type.unsign.min, cs->integer_step.type.unsign.max, cs->integer_step.step);
+
     g_assert(cs->integer_step.type.unsign.cursor >= cs->integer_step.type.unsign.min);
   
     cs->integer_step.estimated_remaining_steps=cs->integer_step.step>0?(cs->integer_step.type.unsign.max - cs->integer_step.type.unsign.cursor) / cs->integer_step.step:1;
@@ -546,7 +565,10 @@ guint process_integer_chunk_step(struct table_job *tj, struct chunk_step_item *c
       cs->integer_step.type.sign.cursor = cs->integer_step.type.sign.max;
     else
       cs->integer_step.type.sign.cursor = cs->integer_step.type.sign.min + cs->integer_step.step - 1;
-//g_message("integer_step.type.sign.cursor: %ld  | integer_step.type.sign.min %ld  | cs->integer_step.type.sign.max : %ld | cs->integer_step.step %ld", cs->integer_step.type.sign.cursor, cs->integer_step.type.sign.min, cs->integer_step.type.sign.max, cs->integer_step.step);
+ 
+    if (cs->integer_step.type.sign.cursor < cs->integer_step.type.sign.min)
+      g_error("integer_step.type.sign.cursor: %"G_GINT64_FORMAT"  | integer_step.type.sign.min %"G_GINT64_FORMAT"  | cs->integer_step.type.sign.max : %"G_GINT64_FORMAT" | cs->integer_step.step %ld", cs->integer_step.type.sign.cursor, cs->integer_step.type.sign.min, cs->integer_step.type.sign.max, cs->integer_step.step);
+ 
     g_assert(cs->integer_step.type.sign.cursor >= cs->integer_step.type.sign.min);
     
     cs->integer_step.estimated_remaining_steps=cs->integer_step.step>0?(cs->integer_step.type.sign.max - cs->integer_step.type.sign.cursor) / cs->integer_step.step:1;
@@ -561,8 +583,12 @@ guint process_integer_chunk_step(struct table_job *tj, struct chunk_step_item *c
   
 
   if (csi->next !=NULL){
+    // Multi column
     if (csi->next->needs_refresh)
-      refresh_integer_min_max(td->thrconn, tj->dbt, csi->next);
+      if (!refresh_integer_min_max(td->thrconn, tj->dbt, csi->next)){
+        trace("No min and max found");
+        goto update_min;
+      }
 
     csi->next->chunk_functions.process( tj , csi->next);
     csi->next->needs_refresh=TRUE;
@@ -573,7 +599,6 @@ guint process_integer_chunk_step(struct table_job *tj, struct chunk_step_item *c
     if (cs->integer_step.is_step_fixed_length) {
       write_table_job_into_file(tj);
     }else{
- 
       GDateTime *from = g_date_time_new_now_local();
       write_table_job_into_file(tj);
       GDateTime *to = g_date_time_new_now_local();
@@ -585,35 +610,41 @@ guint process_integer_chunk_step(struct table_job *tj, struct chunk_step_item *c
       g_date_time_unref(to);
       if (diff > MAX_TIME_PER_QUERY){
         cs->integer_step.step=cs->integer_step.step  / 2;
-        cs->integer_step.step=cs->integer_step.step<csi->chunk_step->integer_step.min_chunk_step_size?csi->chunk_step->integer_step.min_chunk_step_size:cs->integer_step.step;
-//    g_message("Decreasing time: %ld | %ld", diff, tj->chunk_step->integer_step.step);
+        trace("Decreasing step to size %ld due time %ld seconds", cs->integer_step.step, diff);
       }else if (diff < MAX_TIME_PER_QUERY){
         cs->integer_step.step=cs->integer_step.step  * 2 == 0?cs->integer_step.step:cs->integer_step.step  * 2;
-//    g_message("Increasing time: %ld | %ld", diff, tj->chunk_step->integer_step.step);
+        trace("Increasing step to size %ld due time %ld seconds", cs->integer_step.step, diff);
       }
-      cs->integer_step.step = cs->integer_step.step > csi->chunk_step->integer_step.max_chunk_step_size ? 
+//      guint ant=cs->integer_step.step;
+      cs->integer_step.step = csi->chunk_step->integer_step.max_chunk_step_size !=0 && cs->integer_step.step > csi->chunk_step->integer_step.max_chunk_step_size ? 
                               csi->chunk_step->integer_step.max_chunk_step_size :
                               cs->integer_step.step;
-      if (cs->integer_step.step > max_integer_chunk_step_size )
-        cs->integer_step.step=max_integer_chunk_step_size;        
-      if (cs->integer_step.step < min_integer_chunk_step_size)
-        cs->integer_step.step=min_integer_chunk_step_size;
+
+      cs->integer_step.step = csi->chunk_step->integer_step.min_chunk_step_size !=0 && cs->integer_step.step < csi->chunk_step->integer_step.min_chunk_step_size ?
+                              csi->chunk_step->integer_step.min_chunk_step_size :
+                              cs->integer_step.step;
+
+//      trace("After checking: %ld == %ld | max_integer_chunk_step_size=%ld | min_integer_chunk_step_size=%ld", ant, cs->integer_step.step, max_integer_chunk_step_size, min_integer_chunk_step_size);
+
     }
   }
 
 // Step 5: Updating min
+update_min:
   g_mutex_lock(csi->mutex);
   if (csi->status != COMPLETED)
     csi->status = ASSIGNED;
   if (cs->integer_step.is_unsigned){
     if ( cs->integer_step.type.unsign.cursor+1 < cs->integer_step.type.unsign.min){
       // Overflow
+      trace("Overflow due integer_step.type.unsign.cursor: %"G_GUINT64_FORMAT"  | integer_step.type.unsign.min %"G_GUINT64_FORMAT, cs->integer_step.type.unsign.cursor, cs->integer_step.type.unsign.min);
       cs->integer_step.type.unsign.min=cs->integer_step.type.unsign.max;
       cs->integer_step.type.unsign.max--;
     }else
       cs->integer_step.type.unsign.min=cs->integer_step.type.unsign.cursor+1;
   }else{
     if ( cs->integer_step.type.sign.cursor+1 < cs->integer_step.type.sign.min){
+      trace("Overflow due integer_step.type.unsign.cursor: %"G_GUINT64_FORMAT"  | integer_step.type.unsign.min %"G_GINT64_FORMAT, cs->integer_step.type.sign.cursor, cs->integer_step.type.sign.min);
       cs->integer_step.type.sign.min=cs->integer_step.type.sign.max;
       cs->integer_step.type.sign.max--;
     }else
@@ -764,11 +795,13 @@ void update_where_on_integer_step(struct chunk_step_item * csi){
 
 void determine_if_we_can_go_deeper(struct db_table *dbt, struct chunk_step_item * csi, guint64 rows){
   if (dbt->multicolumn && csi->position == 0){
-    if ((csi->chunk_step->integer_step.is_unsigned && (rows / (csi->chunk_step->integer_step.type.unsign.max - csi->chunk_step->integer_step.type.unsign.min) > (dbt->min_chunk_step_size==0?min_integer_chunk_step_size:dbt->min_chunk_step_size))
-        )||(
-        (!csi->chunk_step->integer_step.is_unsigned && (rows / gint64_abs(csi->chunk_step->integer_step.type.sign.max   - csi->chunk_step->integer_step.type.sign.min)   > (dbt->min_chunk_step_size==0?min_integer_chunk_step_size:dbt->min_chunk_step_size))
-       )
-        )){
+    if (
+        // In a multi column table, we will use the first column to split the table.
+        // This calculation will let us know how many rows are we getting on average per first column value
+        // we need to have have at least 1 chunk size per first column to perform multi column spliting
+        ( csi->chunk_step->integer_step.is_unsigned && (rows /         (csi->chunk_step->integer_step.type.unsign.max - csi->chunk_step->integer_step.type.unsign.min) > dbt->min_chunk_step_size))||
+        (!csi->chunk_step->integer_step.is_unsigned && (rows / gint64_abs(csi->chunk_step->integer_step.type.sign.max -   csi->chunk_step->integer_step.type.sign.min) > dbt->min_chunk_step_size))
+       ){
       csi->chunk_step->integer_step.min_chunk_step_size=1;
       csi->chunk_step->integer_step.is_step_fixed_length=TRUE;
       csi->chunk_step->integer_step.max_chunk_step_size=1;
