@@ -52,11 +52,10 @@ gchar *pwd=NULL;
 gboolean overwrite_tables = FALSE;
 gboolean overwrite_unsafe = FALSE;
 
-gboolean innodb_optimize_keys = TRUE;
-gboolean innodb_optimize_keys_per_table = TRUE;
-gboolean innodb_optimize_keys_all_tables = FALSE;
+gboolean optimize_keys = TRUE;
+gboolean optimize_keys_per_table = TRUE;
+gboolean optimize_keys_all_tables = FALSE;
 gboolean kill_at_once = FALSE;
-gboolean enable_binlog = FALSE;
 gboolean disable_redo_log = FALSE;
 enum checksum_modes checksum_mode= CHECKSUM_FAIL;
 gboolean skip_triggers = FALSE;
@@ -101,8 +100,6 @@ gboolean pmm = FALSE;
 
 GHashTable * myloader_initialize_hash_of_session_variables(){
   GHashTable * _set_session_hash=initialize_hash_of_session_variables();
-  if (!enable_binlog)
-    set_session_hash_insert(_set_session_hash,"SQL_LOG_BIN",g_strdup("0"));
   if (commit_count > 1)
     set_session_hash_insert(_set_session_hash,"AUTOCOMMIT",g_strdup("0"));
 
@@ -339,6 +336,7 @@ int main(int argc, char *argv[]) {
     print_string("socket",socket_path);
     print_string("protocol", protocol_str);
     print_bool("compress-protocol",compress_protocol);
+#ifdef WITH_SSL
     print_bool("ssl",ssl);
     print_string("ssl-mode",ssl_mode);
     print_string("key",key);
@@ -347,6 +345,7 @@ int main(int argc, char *argv[]) {
     print_string("capath",capath);
     print_string("cipher",cipher);
     print_string("tls-version",tls_version);
+#endif
     print_list("regex",regex_list);
     print_string("source-db",source_db);
 
@@ -361,15 +360,14 @@ int main(int argc, char *argv[]) {
     print_string("pmm-path",pmm_path);
     print_string("pmm-resolution",pmm_resolution);
 
-    print_bool("enable-binlog",enable_binlog);
-    if (!innodb_optimize_keys){
-      print_string("innodb-optimize-keys",SKIP);
-    }else if(innodb_optimize_keys_per_table){
-      print_string("innodb-optimize-keys",AFTER_IMPORT_PER_TABLE);
-    }else if(innodb_optimize_keys_all_tables){
-      print_string("innodb-optimize-keys",AFTER_IMPORT_ALL_TABLES);
+    if (!optimize_keys){
+      print_string("optimize-keys",SKIP);
+    }else if(optimize_keys_per_table){
+      print_string("optimize-keys",AFTER_IMPORT_PER_TABLE);
+    }else if(optimize_keys_all_tables){
+      print_string("optimize-keys",AFTER_IMPORT_ALL_TABLES);
     }else
-      print_string("innodb-optimize-keys",NULL);
+      print_string("optimize-keys",NULL);
 
     print_bool("no-schemas",no_schemas);
 
@@ -645,10 +643,6 @@ int main(int argc, char *argv[]) {
 
   stop_signal_thread();
 
-  if (logoutfile) {
-    fclose(logoutfile);
-  }
-
 /*
   GList * tl=g_list_sort(conf.table_list, compare_by_time);
   g_message("Import timings:");
@@ -665,6 +659,11 @@ int main(int argc, char *argv[]) {
   if (key_file)  g_key_file_free(key_file);
   g_remove(fifo_directory);
   g_message("Restore completed");
+
+  if (logoutfile) {
+    fclose(logoutfile);
+  }
+
   return errors ? EXIT_FAILURE : EXIT_SUCCESS;
 }
 
