@@ -374,7 +374,7 @@ gboolean execute_use(struct connection_data *cd){
     }
     g_free(query);
   }else{
-    g_warning("Thread %ld: Not able to switch database", cd->thread_id);
+    g_warning("Thread %ld with connection %ld: Not able to switch database",cd->thread_id, cd->connection_id);
   }
   return FALSE;
 }
@@ -384,7 +384,7 @@ void execute_use_if_needs_to(struct connection_data *cd, struct database *databa
     if (cd->current_database==NULL || g_strcmp0(database->real_database, cd->current_database->real_database) != 0){
       cd->current_database=database;
       if (execute_use(cd)){
-        m_critical("Thread %d: Error switching to database `%s` %s: %s", cd->thread_id, cd->current_database->real_database, msg, mysql_error(cd->thrconn));
+        m_critical("Thread %ld with connection %ld: Error switching to database `%s` %s: %s", cd->thread_id, cd->connection_id, cd->current_database->real_database, msg, mysql_error(cd->thrconn));
       }
     }
   }
@@ -456,73 +456,9 @@ void get_database_table_from_file(const gchar *filename,const char *sufix,gchar
   g_strfreev(split);
 }
 
-/*
-void append_alter_table(GString * alter_table_statement, char *table){
-  g_string_append(alter_table_statement,"ALTER TABLE `");
-  g_string_append(alter_table_statement,table);
-  g_string_append(alter_table_statement,"` ");
-}
-
-void finish_alter_table(GString * alter_table_statement){
-  gchar * str=g_strrstr_len(alter_table_statement->str,alter_table_statement->len,",");
-  if ((str - alter_table_statement->str) > (long int)(alter_table_statement->len - 5)){
-    *str=';';
-    g_string_append_c(alter_table_statement,'\n');
-  }else
-    g_string_append(alter_table_statement,";\n");
-}
-*/
 int process_create_table_statement (gchar * statement, GString *create_table_statement, GString *alter_table_statement, GString *alter_table_constraint_statement, struct db_table *dbt, gboolean split_indexes){
   return global_process_create_table_statement(statement, create_table_statement, alter_table_statement, alter_table_constraint_statement, dbt->real_table, split_indexes);
 }
-/*  int flag=0;
-  gchar** split_file= g_strsplit(statement, "\n", -1);
-  gchar *autoinc_column=NULL;
-  append_alter_table(alter_table_statement, dbt->real_table);
-  append_alter_table(alter_table_constraint_statement, dbt->real_table);
-  int fulltext_counter=0;
-  int i=0;
-  for (i=0; i < (int)g_strv_length(split_file);i++){
-    if (split_indexes &&( g_strstr_len(split_file[i],5,"  KEY")
-      || g_strstr_len(split_file[i],8,"  UNIQUE")
-      || g_strstr_len(split_file[i],9,"  SPATIAL")
-      || g_strstr_len(split_file[i],10,"  FULLTEXT")
-      || g_strstr_len(split_file[i],7,"  INDEX")
-      )){
-      // Ignore if the first column of the index is the AUTO_INCREMENT column
-      if ((autoinc_column != NULL) && (g_strrstr(split_file[i],autoinc_column))){
-        g_string_append(create_table_statement, split_file[i]);
-        g_string_append_c(create_table_statement,'\n');
-      }else{
-        flag|=IS_ALTER_TABLE_PRESENT;
-        if (g_strrstr(split_file[i],"  FULLTEXT")) fulltext_counter++;
-        if (fulltext_counter>1){
-          fulltext_counter=1;
-          finish_alter_table(alter_table_statement);
-          append_alter_table(alter_table_statement,dbt->real_table);
-        }
-        g_string_append(alter_table_statement,"\n ADD");
-        g_string_append(alter_table_statement, split_file[i]);
-      }
-    }else{
-      if (g_strstr_len(split_file[i],12,"  CONSTRAINT")){
-        flag|=INCLUDE_CONSTRAINT;
-        g_string_append(alter_table_constraint_statement,"\n ADD");
-        g_string_append(alter_table_constraint_statement, split_file[i]);
-      }else{
-        if (g_strrstr(split_file[i],"AUTO_INCREMENT")){
-          gchar** autoinc_split=g_strsplit(split_file[i],"`",3);
-          autoinc_column=g_strdup_printf("(`%s`", autoinc_split[1]);
-        }
-        g_string_append(create_table_statement, split_file[i]);
-        g_string_append_c(create_table_statement,'\n');
-      }
-    }
-    if (g_strrstr(split_file[i],"ENGINE=InnoDB")) flag|=IS_INNODB_TABLE;
-  }
-  return flag;
-}
-*/
 
 gint compare_dbt(gconstpointer a, gconstpointer b, gpointer table_hash){
   gchar *a_key=build_dbt_key(((struct db_table *)a)->database->real_database,((struct db_table *)a)->table);
