@@ -315,7 +315,7 @@ regex_error:
             }
           }
         }
-        if (innodb_optimize_keys || skip_constraints || skip_indexes ){
+        if (optimize_keys || skip_constraints || skip_indexes ){
           GString *alter_table_statement=g_string_sized_new(512);
           GString *alter_table_constraint_statement=g_string_sized_new(512);
           // Check if it is a /*!40  SET
@@ -325,7 +325,7 @@ regex_error:
           }else{
             // Processing CREATE TABLE statement
             int flag = process_create_table_statement(data->str, create_table_statement, alter_table_statement, alter_table_constraint_statement, dbt, (dbt->rows == 0 || dbt->rows >= 1000000 || skip_constraints || skip_indexes));
-            if (flag & IS_INNODB_TABLE){
+            if (flag & IS_TRX_TABLE){
               if (flag & IS_ALTER_TABLE_PRESENT){
 //                finish_alter_table(alter_table_statement);
                 g_message("Fast index creation will be use for table: %s.%s",dbt->database->real_database,dbt->real_table);
@@ -335,7 +335,7 @@ regex_error:
               }
 //              g_string_append(create_table_statement,g_strjoinv("\n)",g_strsplit(new_create_table_statement->str,",\n)",-1)));
               if (!skip_indexes){
-                if (innodb_optimize_keys)
+                if (optimize_keys)
                   dbt->indexes=alter_table_statement;
                 else if (alter_table_statement!=NULL)
                   g_string_append(create_table_statement,alter_table_statement->str);
