@@ -19,24 +19,24 @@
 
 #include <mysql.h>
 
-#define DETECT_MYSQL_REGEX "^([3-9]\\.[0-9]+\\.[0-9]+)"
-#define DETECT_MARIADB_REGEX "^([0-9]{1,2}\\.[0-9]+\\.[0-9]+)"
-#define DETECT_TIDB_REGEX "TiDB"
-
 enum server_type {
-  SERVER_TYPE_UNKNOWN,
+  SERVER_TYPE_UNKNOWN= 0,
   SERVER_TYPE_MYSQL,
   SERVER_TYPE_TIDB,
   SERVER_TYPE_MARIADB,
-  SERVER_TYPE_PERCONA
+  SERVER_TYPE_PERCONA,
+  SERVER_TYPE_CLICKHOUSE,
+  SERVER_TYPE_DOLT
 };
-int detect_server(MYSQL *conn);
 void detect_server_version(MYSQL * conn);
+gboolean server_support_tablespaces();
 int get_product();
 int get_major();
 int get_secondary();
 int get_revision();
+gboolean is_mysql_like();
 const gchar * get_product_name();
 #endif
 
 
+
